<?php
// $Id: template.php,v 1.2.2.1 2009/05/24 11:27:12 teemule Exp $

/**
 * Mobile_Garland is a Garland inspired mobile optimized Drupal theme.
 * The theme should be used with the Mobile Plugin -module.
 */

/**
 * Names the existing regions in this theme.
 * @return a map of region names
 */
function mobile_garland_regions() {
	return array(
		'left' => t('left sidebar'),
		'right' => t('right sidebar'),
		'content' => t('content'),
		'header' => t('header'),
		'footer' => t('footer')
	);
}

/**
 * Preprocesses template variables.
 * @param hook a hook at hand
 * @param vars variables for the template
 * @return preprocessed variables for the template
 */
function _phptemplate_variables($hook, $vars = array()) {
	if ($hook == 'page') {
		if (module_exists('color')) {
			_color_page_alter($vars);
		}
		if (module_exists('mobileplugin')) {
			$vars['styles'] = _mobileplugin_filter_css($vars['css']);
			$vars['scripts'] = _mobileplugin_filter_js();
			$vars['bodyclasses'] = 'mobile' . _mobileplugin_add_class();
		}
	}
	return $vars;
}

/**
 * Themes the top links.
 * @param links links data
 * @param attributes attributes to add for the element
 * @return top links markup
 */
function phptemplate_toplinks($links, $attributes = array('class' => 'links')) {
	$num_links = count($links);
	if ($num_links == 0) {
		return '';
	}
	$output = '<div'. drupal_attributes($attributes) .'>';
	$i = 1;
	foreach ($links as $key => $link) {

		// Add active or passive class to links.
		$active = (strpos($key, '-active') ? ' active' : ' passive');
		if (isset($link['attributes']) && isset($link['attributes']['class'])) {
			$link['attributes']['class'] .= ' ' . $key;
		}
		else {
			$link['attributes']['class'] = $key;
		}

		// Add first and last classes to links.
		$extra_class = '';
		if ($i == 1) {
			$extra_class .= 'first ';
		}
		if ($i == $num_links) {
			$extra_class .= 'last ';
		}
		$output .= '<span '. drupal_attributes(array('class' => $extra_class . $key . $active)) .'>';

		// Create a link or plain title.
		$html = isset($link['html']) && $link['html'];
		$link['query'] = isset($link['query']) ? $link['query'] : NULL;
		$link['fragment'] = isset($link['fragment']) ? $link['fragment'] : NULL;
		if (isset($link['href'])) {
			// TODO make mobileplugin installed check before the loop..
			//$output .= _mobileplugin_hotkey_link($link, $html);
			$output .= l($link['title'], $link['href'], $link['attributes'], $link['query'], $link['fragment'], FALSE, $html);
		} else if ($link['title']) {
			if (!$html) {
				$link['title'] = check_plain($link['title']);
			}
			$output .= '<span'. drupal_attributes($link['attributes']) .'>'. $link['title'] .'</span>';
		}
		$output .= "</span>\n";
		$i++;
	}
	$output .= '</div>';
	return $output;
}

/**
 * Wraps comments to a stylable element.
 * @param content the comment markup
 * @param type a node type
 * @return full comment markup
 */
function phptemplate_comment_wrapper($content, $type = null) {
	if (!$content || $type == 'forum') {
		return '<div id="comments">' . $content . '</div>';
	}
	return '<div id="comments"><h2 class="comments">' . t('Comments') . '</h2>' . $content . '</div>';
}
